@@ -40,11 +40,12 @@ mInputFile(filename, std::ios::binary)
   mCheckOk();
 
   std::string manufacturer;
-  Find(DT_MANUFACTURER, manufacturer);
+  Find("Manufacturer", manufacturer);
+  Find("CharacterSet", mCharacterSet);
 
   if (manufacturer == "SIEMENS") {
     std::string software;
-    Find(DT_SOFTWAREVERSION, software);
+    Find("SoftwareVersion", software);
     // Is Numaris used with other software versions? 20130409cdt
     if (software == ("VA13F")) {
       mSpecial = Numaris_Dictionary::Instance();
@@ -63,7 +64,7 @@ mInputFile(filename, std::ios::binary)
   } 
   else if (manufacturer.find("Philips") != std::string::npos) {
     std::string modality;
-    Find(DT_MODALITY, modality);
+    Find("Modality", modality);
     if (modality == "MR") {
       mSpecial = PhilipsMr_Dictionary::Instance();
     } else {
@@ -79,6 +80,8 @@ mInputFile(filename, std::ios::binary)
 
 
 ///
+/** Wraps mErrors.none().
+*/
 bool
 DicomFile::IsOk() 
 {
@@ -86,61 +89,82 @@ DicomFile::IsOk()
 }
 
 
-// This is where we put reasons to reject files
+///
+/** If IsOk() returns true, checks for SopInstance, SeriesInstanceUid,
+    InstanceNumber and PhotometricInterpretation elements.  If these
+    are not found, will set appropriate error code.
+*/
+// This is where we put reasons to reject files.
 void
 DicomFile::mCheckOk()
 {
-  if (mErrors.none()) {
+  if (IsOk()) {
 
     std::string s;
 
-    if(!Find("SopInstance", s))
-    mErrors.set(NO_UID);
+    if (!Find("SopInstance", s)) {
+      mErrors.set(NO_UID);
+    }
 
-    if(!Find("SeriesInstanceUid", s)) 
-    mErrors.set(NO_SERIES_UID);
+    if (!Find("SeriesInstanceUid", s)) {
+      mErrors.set(NO_SERIES_UID);
+    }
 
-    if (!Find("InstanceNumber", s)) 
-    mErrors.set(NO_INSTANCE);
+    if (!Find("InstanceNumber", s)) {
+      mErrors.set(NO_INSTANCE);
+    }
 
-    if (!Find("PhotometricInterpretation", s)) 
-    mErrors.set(NO_IMAGE);
+    if (!Find("PhotometricInterpretation", s)) {
+      mErrors.set(NO_IMAGE);
+    }
   }
 }
 
 
 ///
-/**
+/** Tests mErrors, returns a string describing any error conditions.
+    \return A character string.
 */
 const char*
 DicomFile::ErrorMessage() const
 {
-  if (mErrors.none()) 
-  return "No errors.";
+  std::string retval;
 
-  if (mErrors.test(NO_BYTES))
-  return "File is <128 bytes. Not a valid DICOM file.";
+  if (mErrors.none()) {
+    return "No errors.";
+  }
 
-  if (mErrors.test(NO_DICM))
-  return "Unable to read file, possibly not DICOM format.";
+  if (mErrors.test(NO_BYTES)) {
+    return "File is <128 bytes. Not a valid DICOM file.";
+  }
+
+  if (mErrors.test(NO_DICM)) {
+    return "Unable to read file, possibly not DICOM format.";
+  }
   
-  if (mErrors.test(METAFILE_ERROR))
-  return "Problem reading metafile header.";
+  if (mErrors.test(METAFILE_ERROR)) {
+    return "Problem reading metafile header.";
+  }
 
-  if (mErrors.test(TRANSFER_SYNTAX))
-  return "Unsupported transfer syntax.";
+  if (mErrors.test(TRANSFER_SYNTAX)) {
+    return "Unsupported transfer syntax.";
+  }
   
-  if (mErrors.test(NO_SERIES_UID))
-  return "Unable to find series UID.";
+  if (mErrors.test(NO_SERIES_UID)) {
+    return "Unable to find series UID.";
+  }
 
-  if (mErrors.test(NO_UID))
-  return "Unable to find instance UID.";
+  if (mErrors.test(NO_UID)) {
+    return "Unable to find instance UID.";
+  }
 
-  if (mErrors.test(NO_INSTANCE))
-  return "Unable to find instance number.";
+  if (mErrors.test(NO_INSTANCE)) {
+    return "Unable to find instance number.";
+  }
 
-  if (mErrors.test(NO_IMAGE))
-  return "File does not contain image data.";
+  if (mErrors.test(NO_IMAGE)) {
+    return "File does not contain image data.";
+  }
 
   // should never get here, but...
   return "Error reading DICOM file.";
@@ -161,7 +185,7 @@ DicomFile::mInitializeMap() {
   ReadMap["SS"] = ReadStream<wxInt16>::doit;
   ReadMap["UL"] = ReadStream<wxUint32>::doit;
   ReadMap["US"] = ReadStream<wxUint16>::doit;
-  ReadMap["UN"] = ReadStream<std::string>::doit;	// Default
+  ReadMap["UN"] = ReadStream<std::string>::doit;  // Default
 }
 
 
@@ -172,54 +196,54 @@ DicomFile::~DicomFile()
 
 
 ///
-/**
+/** Wraps mFindElement.
+    \param d Reference to a DicomElement to seek.
+    \param input Input stream from which to read.
+    \return True if element is found, false otherwise.
 */
-int
+bool
 DicomFile::FindElement(DicomElement& d, std::istream& input) 
 {
-  if (!input.good()) {
-    return 0;
+  bool retval = false;
+  if (input.good()) {
+    DicomElement e;
+    if (mFindElement(d.tag, e, input)) {
+      if (mVrSyntax == EXPLICIT_VR && e.vr != "OB" && e.vr != "UN") {
+        d.vr = e.vr;
+      }
+      d.value_length = e.value_length;
+      retval = true;
+    }
   }
-
-  DicomElement e;
-  if (!mFindElement(d.tag, e, input)) {
-    return 0;
-  }
-  if (mVrSyntax == EXPLICIT_VR && e.vr != "OB" && e.vr != "UN"  ) {
-    d.vr = e.vr;
-  }
-  d.value_length = e.value_length;
-  
-  return 1;
+  return retval;
 }
 
 
 ///
 /** Determines whether the file is a Siemens syngo file based
     on SoftwareVersion tag and magic string.
-    \return True or false.
+    \return True if SoftwareVersion contains "syngo", false otherwise.
 */
 bool
 DicomFile::IsSyngoFile()
 {
+  bool retval = false;
   std::string software;
-  Find(DT_SOFTWAREVERSION, software);
+  Find("SoftwareVersion", software);
 
-  if (software.find("syngo") == std::string::npos) {
-    return false; // not a syngo file
-  }
-  else {
-    return true;
+  if (software.find("syngo") != std::string::npos) {
+    retval = true;
   }
+  return retval;
 }
 
 
 ///
 /** Seeks magic string in private group 0x0029.
     \param or_val Value to OR with a matching element value. In
-    practice, this will be 0x0010 or 0x0020.
+      practice, this will be 0x0010 or 0x0020.
     \param header A string reference to receive the data found
-    in the matching element.
+      in the matching element.
     \return True if element is found, false otherwise.
 */
 bool
@@ -235,20 +259,16 @@ DicomFile::FindCSAHeader(int or_val, std::string& header)
       std::string creator_name;
       if (Find(creator, creator_name)) {
         if (creator_name == "SIEMENS CSA HEADER") {
-          retval = true;
+          element = (element << 8) | or_val;
+          DicomTag csa_header_info_tag(group, element);
+          if (Find(csa_header_info_tag, header)) {
+            retval = true;
+          }
           break;
         }
       }
     }
-    if (retval) {
-      element = (element << 8) | or_val;
-      DicomTag csa_header_info_tag(group, element);
-      if(Find(csa_header_info_tag, header)) {
-        retval = true;
-      }
-    }
   }
-  //std::cout << "CSAHeader: (" << or_val << "): " << header << std::endl;
   return retval;
 }
 
@@ -289,9 +309,10 @@ bool
 DicomFile::HasSiemensMrHeader()
 {
   bool retval = false;
+  wxUint16 group, element;
+  group = 0x0019;
+
   if (IsSyngoFile()) {
-    wxUint16 group, element;
-    group = 0x0019;
     for (element = 0x0010; element < 0x0100; ++element) {
       DicomElement creator(DicomTag(group, element));
       std::string creator_name;
@@ -375,7 +396,7 @@ DicomFile::ReadCSASeriesHeader(const std::string& search, std::vector<std::strin
 /** Routine to read Siemens' "shadow" header.
     Searches data in 'header' for value given by 'search'.
     Expects to have a successful call to one of the GetCSA*Header
-    methods populate 'header'.
+    methods to populate 'header'.
     \param header
     \param search
     \param value A string reference to hold value found.
@@ -424,7 +445,7 @@ DicomFile::ReadCSAHeader(const std::string& header, const std::string& search, s
       break;
     }
   }
-  //***
+  //*** End duplicate block
 
   pos += 4*4;
 
@@ -437,7 +458,14 @@ DicomFile::ReadCSAHeader(const std::string& header, const std::string& search, s
 
 
 ///
-/**
+/** Routine to read Siemens' "shadow" header.
+    Searches data in 'header' for value given by 'search'.
+    Expects to have a successful call to one of the GetCSA*Header
+    methods to populate 'header'.
+    \param header
+    \param search
+    \param value A vector of strings reference to hold values found.
+    \return 0 if not found, -1 if found but no data, 1 if found and there exists data.
 */
 int
 DicomFile::ReadCSAHeader(const std::string& header, const std::string& search, std::vector<std::string>& value)
@@ -482,7 +510,7 @@ DicomFile::ReadCSAHeader(const std::string& header, const std::string& search, s
       break;
     }
   }
-  //***
+  //*** End duplicate block
 
   pos += 4;
   for (;;) {
@@ -572,29 +600,29 @@ DicomFile::DataDump(const char *filename)
 ///
 /**
 */
-int
-DicomFile::GetHeaderSize()
-{
-  mInputFile.seekg(mBeginning);
-
-  DicomElement element;
-  mReadNextElement(element, mInputFile);
-  while (mInputFile.good() && (element.tag != Tag("PixelData"))) {
-    mReadNextElement(element, mInputFile);
-  }
-  return (static_cast<int>(mInputFile.tellg()) - element.value_length);
-}
+//int
+//DicomFile::GetHeaderSize()
+//{
+//  mInputFile.seekg(mBeginning);
+//
+//  DicomElement element;
+//  mReadNextElement(element, mInputFile);
+//  while (mInputFile.good() && (element.tag != Tag("PixelData"))) {
+//    mReadNextElement(element, mInputFile);
+//  }
+//  return (static_cast<int>(mInputFile.tellg()) - element.value_length);
+//}
 
 
 ///
 /**
 */
-int
-DicomFile::GetFileSize()
-{
-  mInputFile.seekg(0, std::ios::end);
-  return static_cast<int>(mInputFile.tellg());
-}
+//int
+//DicomFile::GetFileSize()
+//{
+//  mInputFile.seekg(0, std::ios::end);
+//  return static_cast<int>(mInputFile.tellg());
+//}
 
 
 ///
@@ -602,45 +630,61 @@ DicomFile::GetFileSize()
     the magic DICOM string.  Leaves file pointer ready to read
     DICOM elements on success, or at beginning of file on failure.
     Sets error code in some cases.
-    \return 0 on failure, 1 if magic DICOM string is found.
+    \return false on failure, true if magic DICOM string is found.
 */
-int 
+bool 
 DicomFile::mSkipPreamble() 
 {  
   //****
-  // This bit of code illustrates a new way of reading DICOM files
+  // This bit of code illustrates a way of reading DICOM files
   // using stream operators. Relies on developing istream>> operators
   // for each data bit to be read. Such data bits provide the means
-  // to read themselves. 201304cdt
+  // to read themselves.  Generally, a DICOM group,element comprise
+  // a "data bit".  201304cdt
+  //  
+  // Preamble is the unused 128 bytes at the start of DICOM files.
   /**
   Preamble p;
   mInputFile >> p;
 
+  // MetaHeader is the byte-swap-agnostic portion of DICOM files.
+  mInputFile >> mh;
+  
+  // The rest of the header must consider byte-ordering, hence the 
+  // setting of transferSyntaxCode.
+  main.transferSyntaxCode = mh.GetMainTransferSyntaxCode();
+  mInputFile >> main;
+  **/
+  
+  // Display fluff, proving we know what we are about.
+  /**
   std::vector<DicomElementInstance>::iterator it;
   std::vector<DicomElementInstance>::iterator it_end;
-
-  MetaHeader mh;
-  mInputFile >> mh;
   it = mh.mhElements.begin();
   it_end = mh.mhElements.end();
   for (; it < it_end; ++it) {
-    std::cout << (*it).tag << ": " << (*it).value_length << " " << (*it).value <<  std::endl;
-    }
-  
-  MainHeader main;
-  main.transferSyntaxCode = mh.getMainTransferSyntaxCode();
+    std::cout << *it << std::endl;
+  }
   std::cout << "transfer code: " << main.transferSyntaxCode << std::endl;
-  mInputFile >> main;
   it = main.mhElements.begin();
   it_end = main.mhElements.end();
   for (; it < it_end; ++it) {
-    std::cout << (*it).tag << ": " << (*it).value_length << " " << (*it).value <<  std::endl;
-    }
-  mInputFile.seekg(0);
+//    if (it->tag.group % 2 == 0) {
+      std::cout << *it << std::endl;
+//    }
+  }
   **/
+
+  // Reset input pointer, as if nothing had happened...
+  //mInputFile.seekg(0);
+
+  //
   //****
+ 
+  bool retval = false;
+  
+  //std::cout << "mSkipPreamble" << std::endl;
   
-  int retval = 0;
   if (mInputFile.is_open()) {
     if (IsOk()) {
       // First 128 bytes of DICOM files are not used.
@@ -652,7 +696,7 @@ DicomFile::mSkipPreamble()
           s += mInputFile.get();
         }
         if (s == "DICM") {
-          retval = 1;
+          retval = true;
         }
         else {
           mErrors.set(NO_DICM);
@@ -667,50 +711,92 @@ DicomFile::mSkipPreamble()
   return retval;
 }
 
-
+///////
+//int
+//DicomFile::mReadMetafile() 
+//{
+//  if (!mInputFile.is_open() || !IsOk()) {
+//    return 0;
+//  }
+//
+//  mBeginning = mInputFile.tellg();
+//  std::streamsize group_length;
+//  int Findresult = Find("MfGroupLength", group_length);
+//  if (!Findresult) {
+//    mErrors.set(METAFILE_ERROR);
+//    return 0;
+//  }
+//
+//  std::streampos meta_file_end = mInputFile.tellg() + 
+//  static_cast<std::streampos>(group_length);
+//
+//  std::string s;
+//  if (!Find("MfTransferSyntax", s)) {
+//    mErrors.set(TRANSFER_SYNTAX);
+//    return 0;
+//  }
+//
+//  // Can only read little endian
+//  if (strcmp(s.c_str(), LEI_UID) == 0) {
+//    mSetTransferSyntax(IMPLICIT_VR, dLITTLE_ENDIAN);
+//  }
+//  else if (strcmp(s.c_str(), LEE_UID) == 0) {
+//    mSetTransferSyntax(EXPLICIT_VR, dLITTLE_ENDIAN);
+//  } 
+//  else {
+//    mErrors.set(TRANSFER_SYNTAX);
+//    return 0;
+//  }
+//
+//  mInputFile.seekg(meta_file_end);
+//  mBeginning = mInputFile.tellg();
+//  return 1;
+//}
+/////////
 ///
-/**
+/** Careful here, substantial rewrite. Compare to 
+    original code above. 20131111cdt
+    \return True if the TransferSyntax is little-endian
+            implicit or little-endian explicit, false
+            otherwise.
 */
-int
+bool
 DicomFile::mReadMetafile() 
 {
-  if (!mInputFile.is_open()) 
-  return 0;
-  if (!IsOk()) 
-  return 0;
+  bool retval = false;
+  if (mInputFile.is_open() && IsOk()) {
 
-  mBeginning = mInputFile.tellg();
-  std::streamsize group_length;
-  int Findresult = Find(DT_MFGROUPLENGTH, group_length);
-  if (!Findresult) {
-    mErrors.set(METAFILE_ERROR);
-    return 0;
+    mBeginning = mInputFile.tellg();
+    std::streamsize group_length;
+    if (Find("MfGroupLength", group_length)) {
+      std::streampos meta_file_end = mInputFile.tellg() + 
+      static_cast<std::streampos>(group_length);
+      std::string s;
+      if (Find("MfTransferSyntax", s)) {
+        // Can only read little endian
+        if (strcmp(s.c_str(), LEI_UID) == 0) {
+          mSetTransferSyntax(IMPLICIT_VR, dLITTLE_ENDIAN);
+          mInputFile.seekg(meta_file_end);
+          mBeginning = mInputFile.tellg();
+          retval = true;
+        }
+        else if (strcmp(s.c_str(), LEE_UID) == 0) {
+          mSetTransferSyntax(EXPLICIT_VR, dLITTLE_ENDIAN);
+          mInputFile.seekg(meta_file_end);
+          mBeginning = mInputFile.tellg();
+          retval = true;
+        } 
+        else {
+          mErrors.set(TRANSFER_SYNTAX);
+        }
+      } else {
+        mErrors.set(TRANSFER_SYNTAX);
+      }
+    } else {
+      mErrors.set(METAFILE_ERROR);
+    }
   }
-
-  std::streampos meta_file_end = mInputFile.tellg() + 
-  static_cast<std::streampos>(group_length);
-
-  std::string s;
-  if(!Find(DT_MFTRANSFERSYNTAX, s)) {
-    mErrors.set(TRANSFER_SYNTAX);
-    return 0;
-  }
-
-  // Can only read little endian
-  if (strcmp(s.c_str(), LEI_UID) == 0) {
-    mSetTransferSyntax(IMPLICIT_VR, dLITTLE_ENDIAN);
-  }
-  else if(strcmp(s.c_str(), LEE_UID) == 0) {
-    mSetTransferSyntax(EXPLICIT_VR, dLITTLE_ENDIAN);
-  }	
-  else {
-    mErrors.set(TRANSFER_SYNTAX);
-    return 0;
-  }
-
-  mInputFile.seekg(meta_file_end);
-  mBeginning = mInputFile.tellg();
-  return 1;
+  return retval;
 }
 
 
@@ -747,8 +833,9 @@ void
 DicomFile::mReadValueRepresentation(DicomElement& e, std::istream& input) 
 {
   // Check VR Syntax, but groups < 0x0008 are always EXPLICIT_VR.
-  if ((mVrSyntax == IMPLICIT_VR) && (e.tag.group >= 0x0008))
-  return;
+  if ((mVrSyntax == IMPLICIT_VR) && (e.tag.group >= 0x0008)) {
+    return;
+  }
   e.vr = input.get();
   e.vr += input.get();
 }
@@ -768,28 +855,28 @@ DicomFile::mReadValueLength(DicomElement& e, std::istream& input)
 
     input.read(reinterpret_cast<char*> (&e.value_length), 
     sizeof(e.value_length));
-    //		e.value_length = ByteSwap (e.value_length);
+    //    e.value_length = ByteSwap (e.value_length);
   }
   // These VR types have a 32-bit value length, see Table 7.1-1
   //  of PS 3.5-2011.
-  else if ( e.vr == "OB" ||	
+  else if ( e.vr == "OB" || 
       e.vr == "OW" || 
       e.vr == "OF" ||   // 20070516cdt
       e.vr == "UT" ||   // 20070516cdt
       e.vr == "SQ" ||
       e.vr == "UN" ) {
 
-    input.ignore(2);	// 2 bytes are reserved
+    input.ignore(2);  // 2 bytes are reserved
     
     input.read(reinterpret_cast<char*> (&e.value_length), 
     sizeof(e.value_length));
-    //			e.value_length = ByteSwap (e.value_length);
+    //      e.value_length = ByteSwap (e.value_length);
   } else {
     
     wxUint16 vl_16;
     input.read(reinterpret_cast<char*> (&vl_16), 
     sizeof(vl_16));
-    //			vl_16 = ByteSwap (vl_16);
+    //      vl_16 = ByteSwap (vl_16);
     e.value_length = static_cast<wxUint32> (vl_16);
   }
 
@@ -802,7 +889,6 @@ DicomFile::mReadValueLength(DicomElement& e, std::istream& input)
 void
 DicomFile::mReadNextElement(DicomElement &rElement, std::istream& input) 
 {
-
   mReadElementTag(rElement, input);
   mReadValueRepresentation(rElement, input);
   mReadValueLength(rElement, input);
@@ -921,36 +1007,39 @@ DicomFile::mReadNextElementAll()
     \param input An input stream.
     \return 
 */
-int
-DicomFile::mFindElement(const DicomTag& tag, DicomElement& element,
-std::istream& input) 
+bool
+DicomFile::mFindElement(const DicomTag& tag, DicomElement& element, std::istream& input) 
 {
+  bool retval = false;
+  
   mReadNextElement(element, input);
 
   if (element.tag == tag) {
-    return 1;
-  }
+    retval = true;
+  } else {
 
-  if ((element.tag > tag) || !input.good() || element.tag == DicomTag(0,0)) {
-    input.clear();
-    if (input == mInputFile) {
-      input.seekg(mBeginning);
-    }
-    else {
-      input.seekg(0);
-    }
-  } 	
+    if ((element.tag > tag) || !input.good() || element.tag == DicomTag(0,0)) {
+      input.clear();
+      if (input == mInputFile) {
+        input.seekg(mBeginning);
+      }
+      else {
+        input.seekg(0);
+      }
+    }   
 
-  while (input.good()) {
-    mReadNextElement(element, input);
-    if (element.tag == tag) {
-      return 1;
+    while (input.good()) {
+      mReadNextElement(element, input);
+      if (element.tag == tag) {
+        retval = true;
+        break;
+      }
+      if (element.tag > tag) {
+        break;
+      } 
     }
-    if (element.tag > tag) {
-      return 0;
-    } 
   }
-  return 0;	
+  return retval;
 }
 
 
@@ -1076,7 +1165,7 @@ std::iostream::pos_type
 DicomFile::GetPixelDataStart()
 {
   if (!foundPixelDataStart) {
-    if (!mInputFile.is_open()) return 0;
+    if (!mInputFile.is_open()) { return 0; }
     mInputFile.clear();
 
     mInputFile.seekg(mBeginning);
