@@ -1,5 +1,5 @@
 /// DicomViewer.h
-/**
+/** Displays DICOM header information in a wxFrame.
 */
 
 #ifndef DICOM_VIEWER_H
@@ -10,12 +10,8 @@
 #include "DicomFile.h"
 
 class wxListView;
-/*
-namespace jcs {
-  class DicomFile;
-  struct DicomElement;
-};
-*/
+
+
 class CSAViewer : public wxFrame
 {
 public:
@@ -57,4 +53,3 @@ private:
 };
 
 #endif
-
