@@ -1,5 +1,5 @@
 /// McPanel.cpp
-/**
+/** Main user interface within McFrame.
 */
 
 #pragma warning( disable : 4786 )
@@ -21,6 +21,8 @@
 #include <wx/filedlg.h>
 #include <wx/dirdlg.h>
 
+#include <map>
+#include <algorithm>
 
 #include "MRIConvert.h"
 #include "Converter.h"
@@ -45,44 +47,38 @@
 #include "SpmOptionsDlg.h"
 #include "MetaOptionsDlg.h"
 #include "OverrideDlg.h"
-
-#include <map>
-#include <algorithm>
+#include "ConfigValues.h"
 
 using namespace jcs;
 
-using std::vector;
-using std::string;
-using std::map;
-
 BEGIN_EVENT_TABLE(McPanel, wxPanel)
 
-EVT_BUTTON(COMMAND_NEW,					McPanel::OnNew)
-EVT_BUTTON(COMMAND_ADD_FILES,			McPanel::OnAddFiles)
-EVT_BUTTON(COMMAND_ADD_DIR,		       	McPanel::OnAddDir)
-EVT_BUTTON(COMMAND_DIRECTORY,			McPanel::OnDirectory)
-EVT_BUTTON(COMMAND_CONVERT,		       	McPanel::OnConvert)
-EVT_BUTTON(COMMAND_REMOVE,		       	McPanel::OnRemove)
-EVT_BUTTON(COMMAND_RENAME,		       	McPanel::OnRename)
-EVT_BUTTON(COMMAND_OPTIONS,		       	McPanel::OnOptions)
-EVT_BUTTON(wxID_EXIT,			       	McPanel::OnQuit)
+EVT_BUTTON(COMMAND_NEW,               McPanel::OnNew)
+EVT_BUTTON(COMMAND_ADD_FILES,         McPanel::OnAddFiles)
+EVT_BUTTON(COMMAND_ADD_DIR,           McPanel::OnAddDir)
+EVT_BUTTON(COMMAND_DIRECTORY,         McPanel::OnDirectory)
+EVT_BUTTON(COMMAND_CONVERT,           McPanel::OnConvert)
+EVT_BUTTON(COMMAND_REMOVE,            McPanel::OnRemove)
+EVT_BUTTON(COMMAND_RENAME,            McPanel::OnRename)
+EVT_BUTTON(COMMAND_OPTIONS,           McPanel::OnOptions)
+EVT_BUTTON(wxID_EXIT,                 McPanel::OnQuit)
 
-EVT_CHOICE(CHOICE_OUTPUT,		       	McPanel::OnChoiceOutput)
+EVT_CHOICE(CHOICE_OUTPUT,             McPanel::OnChoiceOutput)
 
-EVT_TREE_SEL_CHANGED(SOURCE_CTRL,		McPanel::OnSourceSelect)
-EVT_TREE_SEL_CHANGED(OUTPUT_CTRL,		McPanel::OnOutputSelect)
-EVT_TREE_END_LABEL_EDIT(OUTPUT_CTRL,	McPanel::OnEditEnd)
+EVT_TREE_SEL_CHANGED(SOURCE_CTRL,     McPanel::OnSourceSelect)
+EVT_TREE_SEL_CHANGED(OUTPUT_CTRL,     McPanel::OnOutputSelect)
+EVT_TREE_END_LABEL_EDIT(OUTPUT_CTRL,  McPanel::OnEditEnd)
 
-EVT_CONTEXT_MENU(		       	       	McPanel::OnContextMenu)
+EVT_CONTEXT_MENU(                     McPanel::OnContextMenu)
 
-EVT_MENU(COMMAND_REMOVE,       			McPanel::OnRemove)
-EVT_MENU(COMMAND_INFO, 					McPanel::OnInfo)
-EVT_MENU(COMMAND_DICOM,			       	McPanel::OnDicom)
-EVT_MENU(COMMAND_IMAGE,		       		McPanel::OnImage)
-EVT_MENU(COMMAND_DIRECTORY,	       		McPanel::OnDirectory)
-EVT_MENU(COMMAND_RENAME,       			McPanel::OnRename)
+EVT_MENU(COMMAND_REMOVE,              McPanel::OnRemove)
+EVT_MENU(COMMAND_INFO,                McPanel::OnInfo)
+EVT_MENU(COMMAND_DICOM,               McPanel::OnDicom)
+EVT_MENU(COMMAND_IMAGE,               McPanel::OnImage)
+EVT_MENU(COMMAND_DIRECTORY,           McPanel::OnDirectory)
+EVT_MENU(COMMAND_RENAME,              McPanel::OnRename)
 
-EVT_DROP_FILES(	       					McPanel::OnDropFiles)
+EVT_DROP_FILES(                       McPanel::OnDropFiles)
 
 END_EVENT_TABLE()
 
@@ -106,7 +102,7 @@ McPanel::McPanel(wxWindow* parent) : wxPanel(parent, -1)
   panelSizer->Add(0, 10, 0, wxEXPAND);
 
   // add list box
-  mpSourceCtrl = new DicomTreeCtrl(this, SOURCE_CTRL, wxTR_MULTIPLE );
+  mpSourceCtrl = new DicomTreeCtrl(this, SOURCE_CTRL, wxTR_MULTIPLE);
   sSizer->Add(mpSourceCtrl, 1, wxEXPAND);
 
   // add buttons
@@ -125,13 +121,14 @@ McPanel::McPanel(wxWindow* parent) : wxPanel(parent, -1)
   sSizer->Add(sSizer_buttons, 0, wxLEFT, 20);
 
   // add source list box sizer to panel sizer
-  panelSizer->Add(sSizer, 1, wxEXPAND|wxLEFT|wxRIGHT, 20);	
+  panelSizer->Add(sSizer, 1, wxEXPAND|wxLEFT|wxRIGHT, 20);  
 
   // add output selector
   mpOutputChooser = new wxChoice(this, CHOICE_OUTPUT);
-  for (int i = 0; i < OutputFactory::GetNumberOfTypes(); ++i) 
-  mpOutputChooser->Append(wxString(OutputFactory::GetDescription(i), wxConvLocal));
-
+  for (int i = 0; i < OutputFactory::GetNumberOfTypes(); ++i) {
+    mpOutputChooser->Append(wxString(OutputFactory::GetDescription(i), wxConvLocal));
+  }
+  
   mpOutputChooser->SetSize(mpOutputChooser->GetBestSize());
   mpOutputChooser->SetSelection(m_output_type);
 
@@ -144,11 +141,12 @@ McPanel::McPanel(wxWindow* parent) : wxPanel(parent, -1)
 
   // add output tree control
   wxString rootdir;
-  wxConfig::Get()->Read(_T("dir"), &rootdir);
-
-  while (!wxDir::Exists(rootdir)) 
-  rootdir = wxDirSelector(_("Choose a directory for output"));
+  wxConfig::Get()->Read(CFG_dir, &rootdir);
 
+  while (!wxDir::Exists(rootdir)) {
+    rootdir = wxDirSelector(_("Choose a directory for output"));
+  }
+  
   mpOutputCtrl = new NewOutputTreeCtrl(this, OUTPUT_CTRL, rootdir);
 
   oSizer->Add(mpOutputCtrl, 1, wxEXPAND);
@@ -206,17 +204,16 @@ McPanel::McPanel(wxWindow* parent) : wxPanel(parent, -1)
   DragAcceptFiles(true);
   #endif
 
-  // todo: handle dir drop
   if (wxGetApp().argc > 1) {
     for (int i = 1; i < wxGetApp().argc; ++i) {
       wxFileName filename(wxGetApp().argv[i]);
-      if (filename.FileExists())
-      mpConverter->AddFile(filename.GetFullPath());
-
+      if (filename.FileExists()) {
+        mpConverter->AddFile(filename.GetFullPath());
+      }
       else if (filename.DirExists()) {
         wxArrayString files;
-        wxDir::GetAllFiles(filename.GetFullPath(), &files, _T("*.*"));
-        mAddSomeFilesDialog(files, _("Adding files..."));
+        wxDir::GetAllFiles(filename.GetFullPath(), &files);
+        mAddSomeFilesDialog(files);
       }
     }
 
@@ -225,7 +222,6 @@ McPanel::McPanel(wxWindow* parent) : wxPanel(parent, -1)
     RefreshSourceCtrl();
     ShowMessageBox();
     ::wxGetTopLevelParent(this)->Raise();
-
   }
 }
 
@@ -233,7 +229,7 @@ McPanel::McPanel(wxWindow* parent) : wxPanel(parent, -1)
 McPanel::~McPanel()
 {
   wxString rootdir = mpOutputCtrl->GetItemText(mpOutputCtrl->GetRootItem());
-  wxConfig::Get()->Write(_T("dir"), rootdir);
+  wxConfig::Get()->Write(CFG_dir, rootdir);
   delete mpConverter;
 }
 
@@ -242,13 +238,13 @@ McPanel::~McPanel()
 void
 McPanel::RefreshSourceCtrl()
 {
-  vector <string> sv = mpConverter->GetSeriesList();
-  vector<string>::iterator it = sv.begin();
-  vector<string>::iterator it_end = sv.end();
+  std::vector<std::string> sv = mpConverter->GetSeriesList();
+  std::vector<std::string>::iterator it = sv.begin();
+  std::vector<std::string>::iterator it_end = sv.end();
   for (; it != it_end; it++) {
     SeriesHandler* series = mpConverter->GetHandler(*it);
     mpSourceCtrl->AddSeries(series);
-  }	
+  } 
 }
 
 
@@ -258,30 +254,32 @@ McPanel::ResetOutput()
   wxBusyCursor busy;
   mpOutputCtrl->Reset();
   mpOutputCtrl->RefreshList();
-
 }
 
+
 void
 McPanel::SetSplitDirs(bool split)
 {
   mpOutputCtrl->SplitDirectories(split);
 }
 
+
 void
 McPanel::SetSplitSubj(bool split)
 {
   mpOutputCtrl->SplitSubjects(split);
 }
 
+
 void
 McPanel::SetPathInfo(wxString path)
 {
   wxTreeItemId item = mpOutputCtrl->GetSelection();
   wxTreeItemId root = mpOutputCtrl->GetRootItem();
 
-  if (!item.IsOk() || item == root)
-  path = mpOutputCtrl->GetItemText(root);
-
+  if (!item.IsOk() || item == root) {
+    path = mpOutputCtrl->GetItemText(root);
+  }
   else {
     while(item != root) {
       item = mpOutputCtrl->GetItemParent(item);
@@ -289,34 +287,31 @@ McPanel::SetPathInfo(wxString path)
       path.Prepend(mpOutputCtrl->GetItemText(item));
     }
   }
-
   mpPathInfo->SetLabel(path);
-
 }
 
 
 void
 McPanel::ShowMessageBox()
 {
-  // don't bother if no messages
-  if (mpConverter->messages.empty()) return;
-
-  wxWindowDisabler disableAll;
-  MessageListDlg lmd(_("Finished adding files"));
-  Message m;
-  m.push_back(_("File name"));
-  m.push_back(_("Status"));
-  m.push_back(_("Information"));
-  lmd.SetColumns(m);
-  lmd.AddMessages(mpConverter->messages);
-  lmd.ShowModal();
-  mpConverter->messages.clear();
+  if (!mpConverter->messages.empty()) {
+    wxWindowDisabler disableAll;
+    MessageListDlg lmd(_("Finished adding files"));
+    Message m;
+    m.push_back(_("File name"));
+    m.push_back(_("Status"));
+    m.push_back(_("Information"));
+    lmd.SetColumns(m);
+    lmd.AddMessages(mpConverter->messages);
+    lmd.ShowModal();
+    mpConverter->messages.clear();
+  }
 }
 
 
 ///
 /** Helper method for adding files. Handles display of a progress dialog.
-    tuneParam internal variable controls the period of dialog update.
+    Local variable tuneParam controls the period of dialog update.
     \param files List of files to add.
     \param msg Message to display. This is also logged.
 */
@@ -328,16 +323,21 @@ McPanel::mAddSomeFilesDialog(wxArrayString files, const wxChar* msg)
   // Dialog is updated twenty times.
   unsigned int tuneParam = 20;
   unsigned int tuneUpdate = std::max(tuneParam, nfiles / tuneParam);
+  
   wxProgressDialog* p_dlg = new wxProgressDialog(_("Progress"), 
   msg, 
   nfiles,
   this,
   wxPD_CAN_ABORT | wxPD_APP_MODAL | wxPD_SMOOTH);
+  
   files.Sort();
   for (unsigned int i = 0; i < nfiles; ++i) {
     mpConverter->AddFile(files.Item(i).c_str());
-    if (i % tuneUpdate == 0)
-    if (!p_dlg->Update(i)) break;
+    if (i % tuneUpdate == 0) {
+      if (!p_dlg->Update(i)) {
+        break;
+      }
+    }
   }
   p_dlg->Destroy();
 }
@@ -358,8 +358,6 @@ McPanel::OnContextMenu(wxContextMenuEvent& event)
 
   wxTreeItemId item = mpSourceCtrl->HitTest(mpSourceCtrl->ScreenToClient(pos));
   if (item.IsOk()) {
-
-    mpSourceCtrl->SelectItem(item);
     wxMenu menu;
     switch (mpSourceCtrl->GetItemType(item)) {
 
@@ -378,9 +376,9 @@ McPanel::OnContextMenu(wxContextMenuEvent& event)
     }
     PopupMenu(&menu, ScreenToClient(pos));
   }
-
 }
 
+
 void
 McPanel::OnChoiceOutput(wxCommandEvent& event)
 {
@@ -395,37 +393,38 @@ McPanel::OnChoiceOutput(wxCommandEvent& event)
   }
 }
 
+
 void
 McPanel::OnSourceSelect(wxTreeEvent& event)
 {
   // I think we used to enable/disable buttons here...
-
-  // Only do anything if this is a "select" event
-  //	wxTreeItemId item = mpSourceCtrl->GetSelection();
-  //	if (item.IsOk()) mpOutputCtrl->Unselect();
 }
 
+
 void
 McPanel::OnOutputSelect(wxTreeEvent& event)
-{	
+{ 
   // Only do anything if this is a "select" event
   wxTreeItemId item = mpOutputCtrl->GetSelection();
   if (item.IsOk()) {
     SetPathInfo(mpOutputCtrl->GetStringSelection());
-    mpSourceCtrl->Unselect();
+    mpSourceCtrl->UnselectAll();
   }
 }
 
+
 void
 McPanel::OnEditBegin(wxTreeEvent& event)
 {
 }
 
+
 void
 McPanel::OnEditEnd(wxTreeEvent& event)
 {
-  if (!event.IsEditCancelled()) SetPathInfo(event.GetLabel());
-
+  if (!event.IsEditCancelled()) {
+    SetPathInfo(event.GetLabel());
+  }
 }
 
 
@@ -436,35 +435,36 @@ void
 McPanel::OnAddFiles(wxCommandEvent& event)
 {
   wxString lastDir;
-  wxConfig::Get()->Read(_T("lastdir"), &lastDir);
+  wxConfig::Get()->Read(CFG_lastdir, &lastDir);
 
   wxFileDialog dlg(this,
   _("Choose files"),
   lastDir,
-  _T(""),
-  _("DICOM files (*.dcm)|*.dcm|All files|*"),
+  _T(""), _("*"),
   wxFD_OPEN|wxFD_MULTIPLE|wxRESIZE_BORDER);
+//  _("DICOM files (*.dcm)|*.dcm|All files|*"),
 
-  if (dlg.ShowModal() == wxID_OK)	{
-    
+  if (dlg.ShowModal() == wxID_OK) {
     wxBusyCursor busy;
     wxLogStatus(_("Searching directories..."));
     wxArrayString files;
     dlg.GetPaths(files);
-    mAddSomeFilesDialog(files, _("Adding files..."));
+    wxFileName fn(files[0]);
+    lastDir = fn.GetPath();
+    mAddSomeFilesDialog(files);
     mpConverter->UpdateOutput();
     wxLogStatus(_("Creating tree..."));
     RefreshSourceCtrl();
     ResetOutput();
   }
 
-  //dlg.Destroy();
+  wxConfig::Get()->Write(CFG_lastdir, lastDir);
   wxLogStatus(_("Finished."));
   ShowMessageBox();
   ::wxGetTopLevelParent(this)->Raise();
-
 }
 
+
 // Fix: handle dropping dirs too
 ///
 /** Handler for drag-and-drop.
@@ -482,8 +482,8 @@ McPanel::OnDropFiles(wxDropFilesEvent& event)
     }
     else if (filename.DirExists()) {
       wxArrayString files;
-      wxDir::GetAllFiles(filename.GetFullPath(), &files, _T("*.*"));
-      mAddSomeFilesDialog(files, _("Adding files..."));
+      wxDir::GetAllFiles(filename.GetFullPath(), &files);
+      mAddSomeFilesDialog(files);
     }
   }
 
@@ -492,7 +492,6 @@ McPanel::OnDropFiles(wxDropFilesEvent& event)
   RefreshSourceCtrl();
   ShowMessageBox();
   ::wxGetTopLevelParent(this)->Raise();
-
 }
 
 
@@ -503,86 +502,112 @@ void
 McPanel::OnAddDir(wxCommandEvent& event)
 {
   wxString lastDir;
-  wxConfig::Get()->Read(_T("lastdir"), &lastDir);
+  wxConfig::Get()->Read(CFG_lastdir, &lastDir);
 
   wxDirDialog dlg(this,
   _("Select a directory of files to convert"),
   lastDir,
   wxRESIZE_BORDER);
 
-  if(dlg.ShowModal() == wxID_OK)	{
-    
+  if (dlg.ShowModal() == wxID_OK) {
     wxBusyCursor busy;
     wxLogStatus(_("Searching directories..."));
     wxArrayString files;
     wxDir::GetAllFiles(dlg.GetPath(), &files);
-    mAddSomeFilesDialog(files, _("Adding files..."));
+    mAddSomeFilesDialog(files);
     lastDir = dlg.GetPath();
-    wxConfig::Get()->Write(_T("lastdir"), dlg.GetPath());
+    wxConfig::Get()->Write(CFG_lastdir, dlg.GetPath());
   }
 
-  RefreshSourceCtrl();
   mpConverter->UpdateOutput();
   ResetOutput();
+  RefreshSourceCtrl();
   wxLogStatus(_("Finished."));
   ShowMessageBox();
   ::wxGetTopLevelParent(this)->Raise();
 }
 
 
+///
+/** Shows DICOM header information for selected items.
+*/
 void
 McPanel::OnDicom(wxCommandEvent& event)
 {
-  if (mpSourceCtrl->GetSelectionType() == dtFILE) {
-    wxString filename =  mpSourceCtrl->GetStringSelection();
-    DicomViewer* viewer = new DicomViewer(this, filename.mb_str(wxConvLocal)); 
-    viewer->Show();
+  wxArrayTreeItemIds selecteds;
+  unsigned int n_selected = mpSourceCtrl->GetSelected(selecteds);
+
+  for (unsigned int i = 0; i < n_selected; ++i) {
+    if (mpSourceCtrl->GetItemType(selecteds[i]) == dtFILE) {
+      wxString filename = mpSourceCtrl->GetStringSelection(selecteds[i]);
+      DicomViewer* viewer = new DicomViewer(this, filename.mb_str(wxConvLocal)); 
+      viewer->Show();
+    }
   }
 }
 
+
+///
+/** Shows DICOM image for selected items.
+*/
 void
 McPanel::OnImage(wxCommandEvent& event)
 {
-  if (mpSourceCtrl->GetSelectionType() == dtFILE) {
-    wxString filename =  mpSourceCtrl->GetStringSelection();
+  wxArrayTreeItemIds selecteds;
+  unsigned int n_selected = mpSourceCtrl->GetSelected(selecteds);
+  
+  for (unsigned int i = 0; i < n_selected; ++i) {
+    if (mpSourceCtrl->GetItemType(selecteds[i]) == dtFILE) {
+      wxString filename = mpSourceCtrl->GetStringSelection(selecteds[i]);
 
-    DicomFile dfile(filename.mb_str(wxConvLocal));
-    int frames = 1;
-    dfile.Find("NumberOfFrames", frames);
-    if (frames > 1) {
-      MultiFrameImageViewer* viewer = new MultiFrameImageViewer(
-      this, filename);
-      viewer->Show();
+      DicomFile dfile(filename.mb_str(wxConvLocal));
+      int frames = 1;
+      dfile.Find("NumberOfFrames", frames);
+      if (frames > 1) {
+        MultiFrameImageViewer* viewer = new MultiFrameImageViewer(this, filename);
+        viewer->Show();
+      }
+      else {
+        std::vector<wxString> filenames = mpSourceCtrl->GetFilesInSeries(selecteds[i]);
+        ImageViewer* viewer = new ImageViewer(this, filenames, filename);
+        viewer->Show();
+      }
     }
-    else {
-      vector<wxString> filenames = mpSourceCtrl->GetFilesInSeries();
-      ImageViewer* viewer = new ImageViewer(this, filenames, 
-      mpSourceCtrl->GetStringSelection());
-      viewer->Show();
-    }
-    //		viewer->Destroy();
+    // Blank the status bar.
+    wxLogStatus(_T(""));
   }
-  wxLogStatus(_T(""));
 }
 
+
+///
+/** Shows Series information for selected items.
+*/
 void
 McPanel::OnInfo(wxCommandEvent& event)
 {
-  wxTreeItemId selection = mpSourceCtrl->GetSelection();
-  int type = mpSourceCtrl->GetItemType(selection);
+  wxTreeItemId selected;
+  wxArrayTreeItemIds selecteds;
+  unsigned int n_selected = mpSourceCtrl->GetSelected(selecteds);
 
-  if ((type == dtSERIES) || (type == dtFILE)) {
-    wxBusyCursor busy;
-    std::string series_uid;
-    if (type == dtSERIES)
-    series_uid = mpSourceCtrl->GetItemUid(selection);
-    else if (type == dtFILE) {
-      wxTreeItemId series = mpSourceCtrl->GetItemParent(selection);
-      series_uid = mpSourceCtrl->GetItemUid(series);
+  for (unsigned int i = 0; i < n_selected; ++i) {
+
+    wxTreeItemId selection = selecteds[i];
+    int type = mpSourceCtrl->GetItemType(selection);
+
+    if ((type == dtSERIES) || (type == dtFILE)) {
+      wxBusyCursor busy;
+      std::string series_uid;
+      if (type == dtSERIES) {
+        series_uid = mpSourceCtrl->GetItemUid(selection);
+      }
+      else if (type == dtFILE) {
+        wxTreeItemId series = mpSourceCtrl->GetItemParent(selection);
+        series_uid = mpSourceCtrl->GetItemUid(series);
+      }
+      std::vector<std::string> info = mpConverter->GetStringInfo(series_uid);
+      InfoFrame* infoFrame = new InfoFrame(this, info);
+      infoFrame->Show();
     }
-    std::vector<std::string> info = mpConverter->GetStringInfo(series_uid);
-    InfoFrame* infoFrame = new InfoFrame(this, info);
-    infoFrame->Show();
   }
 }
 
@@ -594,30 +619,31 @@ McPanel::OnInfo(wxCommandEvent& event)
 void
 McPanel::OnRemove(wxCommandEvent& event)
 {
-  wxTreeItemId selected;  // = mpSourceCtrl->GetSelection();
+  wxTreeItemId selected;
   wxArrayTreeItemIds selecteds;
-  unsigned int n_selected = mpSourceCtrl->GetSelections(selecteds);
+  unsigned int n_selected = mpSourceCtrl->GetSelected(selecteds);
 
   for (unsigned int i = 0; i < n_selected; ++i) {
     selected = selecteds[i];
-    if(!selected.IsOk()) return;
+    if (selected.IsOk()) {
+      if (mpSourceCtrl->GetSelectionType() == dtFILE) {
+        wxLogError(_("Sorry, you'll have to remove the whole series."));
+        return;
+      }
 
-    if (mpSourceCtrl->GetSelectionType() == dtFILE) {
-      wxLogError(_("Sorry, you'll have to remove the whole series."));
+      std::vector<std::string> series_vector = mpSourceCtrl->GetChildSeries(selected);
+
+      std::vector<std::string>::iterator it = series_vector.begin();
+      while (it < series_vector.end()) {
+        mpConverter->RemoveSeries(*it);
+        mpOutputCtrl->RemoveSeries(*it);
+        ++it;
+      }
+
+      mpSourceCtrl->RemoveBranch(selected);
+    } else {
       return;
     }
-
-    std::vector<std::string> series_vector = 
-    mpSourceCtrl->GetChildSeries(selected);
-
-    std::vector<std::string>::iterator it = series_vector.begin();
-    while (it < series_vector.end()) {
-      mpConverter->RemoveSeries(*it);
-      mpOutputCtrl->RemoveSeries(*it);
-      ++it;
-    }
-
-    mpSourceCtrl->RemoveBranch(selected);
   }
 }
 
@@ -625,18 +651,20 @@ McPanel::OnRemove(wxCommandEvent& event)
 void
 McPanel::OnOptions(wxCommandEvent& event)
 {
-  if (ShowOptionsDlg(m_output_type, mpConverter->GetOutputter()) == 1) {
+  if (ShowOptionsDlg(m_output_type, mpConverter->GetOutputter())) {
     mpConverter->UpdateAllOutput();
     ResetOutput();
   }
 }
 
+
 void
 McPanel::OnDirectory(wxCommandEvent& event)
 {
   mpOutputCtrl->ChooseRootDir();
 }
 
+
 void
 McPanel::OnNew(wxCommandEvent& event)
 {
@@ -649,6 +677,7 @@ McPanel::OnNew(wxCommandEvent& event)
   mpOutputCtrl->GetForegroundColour());
 }
 
+
 void
 McPanel::OnConvert(wxCommandEvent& event)
 {
@@ -660,14 +689,18 @@ McPanel::OnConvert(wxCommandEvent& event)
   ::wxGetTopLevelParent(this)->Raise();
 }
 
+
 void
 McPanel::OnRename(wxCommandEvent& event)
 {
   mpOutputCtrl->OnMenuRename(event);
   wxString pathInfo = mpOutputCtrl->GetStringSelection();
-  if (pathInfo != _T("error")) SetPathInfo(pathInfo);
+  if (pathInfo != _T("error")) {
+    SetPathInfo(pathInfo);
+  }
 }
 
+
 void
 McPanel::OnMenuOverride()
 {
@@ -675,73 +708,92 @@ McPanel::OnMenuOverride()
   mpOutputCtrl->OnMenuOverride(nullEvent);
 }
 
+
 void
 McPanel::OnOverride(const std::string& seriesUid)
 {
-  if (ShowOverride(m_output_type, mpConverter->GetOutputter(), seriesUid) == 1) {
+  if (ShowOverride(m_output_type, mpConverter->GetOutputter(), seriesUid)) {
     mpConverter->UpdateAllOutput();
     ResetOutput();
   }
-
 }
 
-int
+
+bool
 McPanel::ShowOptionsDlg(int type, OutputterBase* outputter)
 {
-  bool rebuild = 0;
+  bool needsRebuild = false;
 
   switch (type) {
 
   case OutputFactory::SPM : {
-      SpmOptionsDlg* dlg = new SpmOptionsDlg(dynamic_cast<NewSpmOutputter*>(outputter));
-      if (dlg->ShowModal() == wxID_OK) rebuild = dlg->NeedsRebuild();
-      dlg->Destroy();}
+        SpmOptionsDlg* dlg = new SpmOptionsDlg(dynamic_cast<NewSpmOutputter*>(outputter));
+        if (dlg->ShowModal() == wxID_OK) {
+          needsRebuild = dlg->NeedsRebuild();
+        }
+        dlg->Destroy();
+      }
     break;
 
   case OutputFactory::META : {
       MetaOptionsDlg* dlg = new MetaOptionsDlg(dynamic_cast<NewMetaOutputter*>(outputter));
-      if (dlg->ShowModal() == wxID_OK) rebuild = dlg->NeedsRebuild();
-      dlg->Destroy(); }
+      if (dlg->ShowModal() == wxID_OK) {
+        needsRebuild = dlg->NeedsRebuild();
+      }
+      dlg->Destroy();
+      }
     break;
 
   case OutputFactory::NIFTI : {
       NiftiOptionsDlg* dlg = new NiftiOptionsDlg(dynamic_cast<NiftiOutputterBase*>(outputter));
-      if (dlg->ShowModal() == wxID_OK) rebuild = dlg->NeedsRebuild();
-      dlg->Destroy(); }
+      if (dlg->ShowModal() == wxID_OK) {
+        needsRebuild = dlg->NeedsRebuild();
+      }
+      dlg->Destroy();
+      }
     break;
 
   case OutputFactory::ANALYZE : {
       AnalyzeOptionsDlg* dlg = new AnalyzeOptionsDlg(dynamic_cast<AnalyzeOutputter*>(outputter));
-      if (dlg->ShowModal() == wxID_OK) rebuild = dlg->NeedsRebuild();
-      dlg->Destroy(); }
+      if (dlg->ShowModal() == wxID_OK) {
+        needsRebuild = dlg->NeedsRebuild();
+      }
+      dlg->Destroy();
+      }
     break;
 
   case OutputFactory::FSL : {
       NiftiOptionsDlg* dlg = new NiftiOptionsDlg(dynamic_cast<NiftiOutputterBase*>(outputter));
-      if (dlg->ShowModal() == wxID_OK) rebuild = dlg->NeedsRebuild();
-      dlg->Destroy(); }
+      if (dlg->ShowModal() == wxID_OK) {
+        needsRebuild = dlg->NeedsRebuild();
+      }
+      dlg->Destroy();
+      }
     break;
 
   case OutputFactory::BV : {
       BvOptionsDlg* dlg = new BvOptionsDlg(dynamic_cast<NewBvOutputter*>(outputter));
-      if (dlg->ShowModal() == wxID_OK) rebuild = dlg->NeedsRebuild();
-      dlg->Destroy(); }
+      if (dlg->ShowModal() == wxID_OK) {
+        needsRebuild = dlg->NeedsRebuild();
+      }
+      dlg->Destroy();
+      }
     break;
 
     default : {
       NoOptionsDlg* dlg = new NoOptionsDlg();
       dlg->ShowModal();
-      dlg->Destroy(); }
+      dlg->Destroy();
+      }
   }
-
-  return static_cast<int>(rebuild);
+  return needsRebuild;
 }
 
 
-int 
-McPanel::ShowOverride(int type, OutputterBase* outputter, const string& series_uid)
+bool 
+McPanel::ShowOverride(int type, OutputterBase* outputter, const std::string& series_uid)
 {
-  int needsRebuild = 0;
+  bool needsRebuild = false;
   if (type == OutputFactory::BV) {
     wxLogMessage(_("It is not possible to override default options for BrainVoyager output."));
     return needsRebuild;
@@ -751,12 +803,14 @@ McPanel::ShowOverride(int type, OutputterBase* outputter, const string& series_u
   dlg.dimCheck->SetValue(basicOutputter->GetDimensionality(series_uid) == 4);
   dlg.skipSpin->SetValue(basicOutputter->GetSkip(series_uid));
   if (dlg.ShowModal() == wxID_OK) {
-    if (dlg.dimCheck->GetValue())
-    basicOutputter->SetDimensionality(series_uid, 4);
-    else
-    basicOutputter->SetDimensionality(series_uid, 3);
+    if (dlg.dimCheck->GetValue()) {
+      basicOutputter->SetDimensionality(series_uid, 4);
+    }
+    else {
+      basicOutputter->SetDimensionality(series_uid, 3);
+    }
     basicOutputter->SetSkip(series_uid, dlg.skipSpin->GetValue());
-    needsRebuild = 1;
+    needsRebuild = true;
   }
   return needsRebuild;  
 }
