@@ -7,7 +7,7 @@
 using namespace jcs;
 
 bool
-MetaHeader::isMetaHeaderElement(DicomElementInstance de)
+MetaHeader::IsMetaHeaderElement(DicomElementInstance de)
 {
   bool retval = false;
   if (de.tag.group == 0x0002) {
@@ -16,26 +16,30 @@ MetaHeader::isMetaHeaderElement(DicomElementInstance de)
   return retval;
 }
 
+
+///
+/** Gets the transfer syntax for the main part of the file.
+*/
 wxUint8
-MetaHeader::getMainTransferSyntaxCode()
+MetaHeader::GetMainTransferSyntaxCode()
 {
-  wxUint8 retval;
+  wxUint8 retval = LEI_CODE; // Default transfer syntax for DICOM.
   std::vector<DicomElementInstance>::iterator it = mhElements.begin();
   std::vector<DicomElementInstance>::iterator it_end = mhElements.end();
   for (; it < it_end; ++it) {
-    //std::cout << "Meta compare: " << it->tag << " and " << DT_MFTRANSFERSYNTAX << std::endl;
     if (it->tag == DT_MFTRANSFERSYNTAX) {
-      //std::cout << "MF syntax: " << it->value << std::endl;
-      if (it->value.compare(LEE_UID))
+      if (it->myValue->first().Cmp(wxString::FromAscii(LEE_UID))) {
         retval = LEE_CODE;
-      if (it->value.compare(LEI_UID))
+      }
+      if (it->myValue->first().Cmp(wxString::FromAscii(LEI_UID))) {
         retval = LEI_CODE;
-      if (it->value.compare(BEE_UID))
+      }
+      if (it->myValue->first().Cmp(wxString::FromAscii(BEE_UID))) {
         retval = BEE_CODE;
+      }
       break;
     }
   }
-  //std::cout << "MF syntax: " << retval << std::endl;
   return retval;
 }
 
@@ -46,13 +50,11 @@ jcs::operator>> (std::istream &in, MetaHeader &mh)
   DicomElementInstance de;
   de.transferSyntaxCode = LEE_CODE;
   std::streampos save_position;
-  while (1) {
+  while (true) {
     save_position = in.tellg();
     in >> de;
-    //std::cout << "metaheader de: " << de.tag << std::endl;
-    if (mh.isMetaHeaderElement(de)) {
+    if (mh.IsMetaHeaderElement(de)) {
       mh.mhElements.push_back(de);
-      de.value.assign("");
     }
     else {
       in.seekg(save_position);
