@@ -180,7 +180,9 @@ int
 SeriesHandler::GetRescaleSlopeAndIntercept(const VolId& id, double& slope, double& intercept) const
 {
   std::string filename;
-  if (!GetFirstFilename(id, filename)) { return 0; }
+  if (!GetFirstFilename(id, filename)) {
+    return 0;
+  }
   DicomFile dicomFile(filename.c_str());
   return GetRescaleSlopeAndIntercept(dicomFile, slope, intercept);
 }
@@ -193,8 +195,12 @@ SeriesHandler::GetRescaleSlopeAndIntercept(const VolId& id, double& slope, doubl
 int
 SeriesHandler::GetRescaleSlopeAndIntercept(DicomFile& dfile, double& slope, double& intercept, int frame) const
 {
-  if (!dfile.Find("RescaleSlope", slope)) { slope = 1; }
-  if (!dfile.Find("RescaleIntercept", intercept)) { intercept = 0; }
+  if (!dfile.Find("RescaleSlope", slope)) {
+    slope = 1;
+  }
+  if (!dfile.Find("RescaleIntercept", intercept)) {
+    intercept = 0;
+  }
   return 1;
 }
 
@@ -539,10 +545,12 @@ SeriesHandler::ReadVolIds(DicomFile& file)
     info.ids.push_back(GetSeriesUid());
     
     // Make info.ids unique in event of multi-frame series.
+    /**
     std::stringstream ss;
     ss << frameno;
     info.ids.push_back(ss.str());
-    
+    */
+
     std::string str;
     file.Find("NumberOfTemporalPositions", str);
     int ndigits = str.size();
@@ -585,8 +593,8 @@ SeriesHandler::ReadVolIds(DicomFile& file)
         info.ids.push_back("");
       }
     }
-    std::vector<double> rotation;
-    rotation.resize(9, 0);
+    std::vector<double> rotation(9,0);
+    //rotation.resize(9, 0);
 
     std::string iop;
     if (!file.Find("ImageOrientationPatient", iop)) {
@@ -613,29 +621,10 @@ SeriesHandler::ReadVolIds(DicomFile& file)
       orientations.push_back(rotation);
     }
     info.ids.push_back(itos(info.orientNumber + 1));
-
-    /**
-    if (std::find(v.begin(), v.end(), info) != v.end()) {
-      std::cout << "info already exists, VolId collision" << std::endl;
-    }
-    **/
     
     v.push_back(info);
   }
 
-  /**
-  VolListType::iterator it = v.begin();
-  VolListType::iterator it_end = v.end();
-  for (; it < it_end; ++it) {
-    VolId::IdType::iterator iter = it->ids.begin();
-    VolId::IdType::iterator iter_end = it->ids.end();
-    for (; iter < iter_end; ++iter) {
-      std::cout << *iter << " ";
-    }
-    std::cout << std::endl;
-  }
-  **/
-
   return v;
 }
 
